[asterisk-commits] kmoore: branch kmoore/stasis-bridge_events r384747 - in /team/kmoore/stasis-b...

SVN commits to the Asterisk project asterisk-commits at lists.digium.com
Thu Apr 4 11:30:31 CDT 2013


Author: kmoore
Date: Thu Apr  4 11:30:28 2013
New Revision: 384747

URL: http://svnview.digium.com/svn/asterisk?view=rev&rev=384747
Log:
Multiple revisions 384618,384672,384712,384745

........
  r384618 | root | 2013-04-03 11:17:20 -0500 (Wed, 03 Apr 2013) | 11 lines
  
  astobj2: Fix rbtree duplicate handling.
  
  OBJ_PARTIAL_KEY searching a rbtree did not find all possible matches if
  the container did not accept duplicates.
  
  Added matching node bias to indicate which matching node is being searched
  for: first, last, any.
  ........
  
  Merged revisions 384616 from file:///srv/subversion/repos/asterisk/trunk
........
  r384672 | root | 2013-04-03 13:17:20 -0500 (Wed, 03 Apr 2013) | 13 lines
  
  Update documentation for CHANNEL function
  
  Document that you can read/write the 'accountcode' and 'amaflags' on a channel.
  ........
  
  Merged revisions 384640 from http://svn.asterisk.org/svn/asterisk/branches/1.8
  ........
  
  Merged revisions 384641 from http://svn.asterisk.org/svn/asterisk/branches/11
  ........
  
  Merged revisions 384642 from file:///srv/subversion/repos/asterisk/trunk
........
  r384712 | root | 2013-04-03 16:17:19 -0500 (Wed, 03 Apr 2013) | 40 lines
  
  Multiple revisions 384696,384711
  
  ........
    r384696 | rmudgett | 2013-04-03 15:20:09 -0500 (Wed, 03 Apr 2013) | 26 lines
    
    chan_dahdi: Add inband_on_proceeding compatibility option.
    
    The new inband_on_proceeding option causes Asterisk to assume inband audio
    may be present when a PROCEEDING message is received.
    
    Q.931 Section 5.1.2 says the network cannot assume that the CPE side has
    attached to the B channel at this time without explicitly sending the
    progress indicator ie informing the CPE side to attach to the B channel
    for audio.  However, some non-compliant ISDN switches send a PROCEEDING
    without the progress indicator ie indicating inband audio is available and
    assume that the CPE device has connected the media path for listening to
    ringback and other messages.
    
    ASTERISK-17834 which causes this issue was dealing with a non-compliant
    network switch.
    
    (closes issue ASTERISK-21151)
    Reported by: Gianluca Merlo
    Tested by: rmudgett
    ........
    
    Merged revisions 384685 from http://svn.asterisk.org/svn/asterisk/branches/1.8
    ........
    
    Merged revisions 384689 from http://svn.asterisk.org/svn/asterisk/branches/11
  ........
    r384711 | rmudgett | 2013-04-03 15:27:11 -0500 (Wed, 03 Apr 2013) | 4 lines
    
    chan_dahdi: Change inband_on_proceeding option default to no/disabled.
    
    (issue ASTERISK-21151)
  ........
  
  Merged revisions 384696,384711 from file:///srv/subversion/repos/asterisk/trunk
........
  r384745 | kmoore | 2013-04-04 11:25:09 -0500 (Thu, 04 Apr 2013) | 2 lines
  
  Strip ast_ prefixes from static functions
........

Merged revisions 384618,384672,384712,384745 from http://svn.asterisk.org/svn/asterisk/team/group/bridge_construction

Modified:
    team/kmoore/stasis-bridge_events/   (props changed)
    team/kmoore/stasis-bridge_events/main/bridging.c

Propchange: team/kmoore/stasis-bridge_events/
------------------------------------------------------------------------------
--- svnmerge-integrated (original)
+++ svnmerge-integrated Thu Apr  4 11:30:28 2013
@@ -1,1 +1,1 @@
-/team/group/bridge_construction:1-384609
+/team/group/bridge_construction:1-384746

Modified: team/kmoore/stasis-bridge_events/main/bridging.c
URL: http://svnview.digium.com/svn/asterisk/team/kmoore/stasis-bridge_events/main/bridging.c?view=diff&rev=384747&r1=384746&r2=384747
==============================================================================
--- team/kmoore/stasis-bridge_events/main/bridging.c (original)
+++ team/kmoore/stasis-bridge_events/main/bridging.c Thu Apr  4 11:30:28 2013
@@ -109,7 +109,7 @@
  *
  * \return Nothing
  */
-static void ast_bridge_manager_service_req(struct ast_bridge *bridge)
+static void bridge_manager_service_req(struct ast_bridge *bridge)
 {
 	struct bridge_manager_request *request;
 
@@ -269,7 +269,7 @@
  *
  * \return Nothing
  */
-static void ast_bridge_queue_action_nodup(struct ast_bridge *bridge, struct ast_frame *action)
+static void bridge_queue_action_nodup(struct ast_bridge *bridge, struct ast_frame *action)
 {
 	ast_debug(1, "Bridge %s: queueing action type:%d sub:%d\n",
 		bridge->uniqueid, action->frametype, action->subclass.integer);
@@ -277,7 +277,7 @@
 	ast_bridge_lock(bridge);
 	AST_LIST_INSERT_TAIL(&bridge->action_queue, action, frame_list);
 	ast_bridge_unlock(bridge);
-	ast_bridge_manager_service_req(bridge);
+	bridge_manager_service_req(bridge);
 }
 
 int ast_bridge_queue_action(struct ast_bridge *bridge, struct ast_frame *action)
@@ -288,7 +288,7 @@
 	if (!dup) {
 		return -1;
 	}
-	ast_bridge_queue_action_nodup(bridge, dup);
+	bridge_queue_action_nodup(bridge, dup);
 	return 0;
 }
 
@@ -389,7 +389,7 @@
  *
  * \return Nothing
  */
-static void ast_bridge_channel_pull(struct ast_bridge_channel *bridge_channel)
+static void bridge_channel_pull(struct ast_bridge_channel *bridge_channel)
 {
 	struct ast_bridge *bridge = bridge_channel->bridge;
 
@@ -436,7 +436,7 @@
  *
  * \return Nothing
  */
-static void ast_bridge_channel_push(struct ast_bridge_channel *bridge_channel)
+static void bridge_channel_push(struct ast_bridge_channel *bridge_channel)
 {
 	struct ast_bridge *bridge = bridge_channel->bridge;
 	struct ast_bridge_channel *swap;
@@ -490,7 +490,7 @@
 	}
 	if (swap) {
 		ast_bridge_change_state(swap, AST_BRIDGE_CHANNEL_STATE_HANGUP);
-		ast_bridge_channel_pull(swap);
+		bridge_channel_pull(swap);
 	}
 
 	bridge->reconfigured = 1;
@@ -649,7 +649,7 @@
  *
  * \param bridge_channel Bridge channel the notification was received on
  */
-static void ast_bridge_handle_trip(struct ast_bridge_channel *bridge_channel)
+static void bridge_handle_trip(struct ast_bridge_channel *bridge_channel)
 {
 	struct ast_frame *frame;
 
@@ -1370,7 +1370,7 @@
 	if (old_technology->destroy) {
 		ast_debug(1, "Bridge %s: deferring %s technology destructor\n",
 			bridge->uniqueid, old_technology->name);
-		ast_bridge_queue_action_nodup(bridge, deferred_action);
+		bridge_queue_action_nodup(bridge, deferred_action);
 	} else {
 		ast_debug(1, "Bridge %s: calling %s technology destructor\n",
 			bridge->uniqueid, old_technology->name);
@@ -1388,8 +1388,8 @@
  * \param bridge Reconfigured bridge.
  *
  * \details
  * After a series of ast_bridge_channel_push and
  * ast_bridge_channel_pull calls, you need to call this function
  * to cause the bridge to complete restruturing for the change
  * in the channel makeup of the bridge.
  *
@@ -1397,7 +1397,7 @@
  *
  * \return Nothing
  */
-static void ast_bridge_reconfigured(struct ast_bridge *bridge)
+static void bridge_reconfigured(struct ast_bridge *bridge)
 {
 	if (!bridge->reconfigured) {
 		return;
@@ -1934,7 +1934,7 @@
 			&& bridge_channel->state == AST_BRIDGE_CHANNEL_STATE_WAIT) {
 			if (chan) {
 				bridge_channel_handle_interval(bridge_channel);
-				ast_bridge_handle_trip(bridge_channel);
+				bridge_handle_trip(bridge_channel);
 			} else if (-1 < outfd) {
 				bridge_channel_handle_write(bridge_channel);
 			}
@@ -1966,8 +1966,8 @@
 		bridge_channel->bridge->callid = ast_read_threadstorage_callid();
 	}
 
-	ast_bridge_channel_push(bridge_channel);
-	ast_bridge_reconfigured(bridge_channel->bridge);
+	bridge_channel_push(bridge_channel);
+	bridge_reconfigured(bridge_channel->bridge);
 
 	/*
 	 * Indicate a source change since this channel is entering the
@@ -1989,8 +1989,8 @@
 	}
 	bridge_channel_lock_bridge(bridge_channel);
 
-	ast_bridge_channel_pull(bridge_channel);
-	ast_bridge_reconfigured(bridge_channel->bridge);
+	bridge_channel_pull(bridge_channel);
+	bridge_reconfigured(bridge_channel->bridge);
 
 	/* See if we need to dissolve the bridge itself if they hung up */
 	switch (bridge_channel->state) {
@@ -2434,7 +2434,7 @@
 /* BUGBUG this needs more work.  The channels need to be made compatible again if the formats change. The bridge_channel thread needs to monitor for this case. */
 		/* The channel we want to notify is still in a bridge. */
 		bridge->v_table->notify_masquerade(bridge, bridge_channel);
-		ast_bridge_reconfigured(bridge);
+		bridge_reconfigured(bridge);
 	}
 	ast_bridge_unlock(bridge);
 	ao2_ref(bridge_channel, -1);
@@ -2702,7 +2702,7 @@
  * this operation is completed.  The caller must explicitly call
  * ast_bridge_destroy().
  */
-static void ast_bridge_merge_do(struct ast_bridge *bridge1, struct ast_bridge *bridge2)
+static void bridge_merge_do(struct ast_bridge *bridge1, struct ast_bridge *bridge2)
 {
 	struct ast_bridge_channel *bridge_channel;
 
@@ -2711,7 +2711,7 @@
 
 	/* Move channels from bridge2 over to bridge1 */
 	while ((bridge_channel = AST_LIST_FIRST(&bridge2->channels))) {
-		ast_bridge_channel_pull(bridge_channel);
+		bridge_channel_pull(bridge_channel);
 
 		/* Point to new bridge.*/
 		ao2_ref(bridge1, +1);
@@ -2720,10 +2720,10 @@
 		ast_bridge_channel_unlock(bridge_channel);
 		ao2_ref(bridge2, -1);
 
-		ast_bridge_channel_push(bridge_channel);
-	}
-	ast_bridge_reconfigured(bridge1);
-	ast_bridge_reconfigured(bridge2);
+		bridge_channel_push(bridge_channel);
+	}
+	bridge_reconfigured(bridge1);
+	bridge_reconfigured(bridge2);
 
 	ast_debug(1, "Merged bridge %s into bridge %s\n",
 		bridge2->uniqueid, bridge1->uniqueid);
@@ -2760,7 +2760,7 @@
 	} else {
 		++bridge1->inhibit_merge;
 		++bridge2->inhibit_merge;
-		ast_bridge_merge_do(bridge1, bridge2);
+		bridge_merge_do(bridge1, bridge2);
 		--bridge2->inhibit_merge;
 		--bridge1->inhibit_merge;
 		res = 0;
@@ -1388,8 +1388,8 @@
  *
  * \details
- * After a series of ast_bridge_channel_push and
- * ast_bridge_channel_pull calls, you need to call this function
+ * After a series of bridge_channel_push and
+ * bridge_channel_pull calls, you need to call this function
  * to cause the bridge to complete restruturing for the change
  * in the channel makeup of the bridge.




More information about the asterisk-commits mailing list